@@ -251,6 +251,9 @@ class ExportItem:
 
 
 class ExportBase:
+    """
+    导出基类，用于将统计数据导出到Excel当中
+    """
 
     def __init__(self, getNode, getX, getY, getUnit):
         self.items: [ExportItem] = []
@@ -309,8 +312,100 @@ class ExportBase:
                 yMerge))
         return self
 
-    def innerExportExcel(self, savePath: str,
-                         xName: str = "Times", xUnit: str = "Second"):
+    def selectSum(self, nodeList: [NodeItem], label: str = None):
+        xMerge = []
+        yArr = []
+
+        for nodeItem in nodeList:
+            node = self.getNode(nodeItem.nodeName)
+            x, y = self.getX(node, nodeItem.nodeId), self.getY(node, nodeItem.nodeId)
+            if not node:
+                print("not exist node: ", node)
+                continue
+            if len(x) > len(xMerge):
+                xMerge = x
+            yArr.append(np.array(y))
+
+        if len(yArr) <= 0:
+            return self
+
+        yMerge = np.zeros(len(xMerge))
+
+        # pad y
+        for y in yArr:
+            y = np.pad(y, (0, len(xMerge) - len(y)), 'constant', constant_values=(0, 0))
+            yMerge += y
+        self.items.append(
+            ExportItem(
+                label,
+                self.getUnit(),
+                label,
+                xMerge,
+                yMerge))
+        return self
+
+    def exportCDFExcel(self, savePath: str,
+                       xName: str = "Rate",
+                       yName: str = "CDF"):
+        """
+        计算CDF（Cumulative Distribution Function）并导出
+        :param xName:
+        :param yName:
+        :param savePath:
+        :return:
+        """
+        longNames, units, labels = [], [], []
+        ys, maxLen = [], 0
+
+        for item in self.items:
+            maxLen = max(maxLen, len(item.y))
+
+        for item in self.items:
+            y = np.array(np.pad(item.y, (0, maxLen - len(item.y)), 'constant', constant_values=(0, 0))).T
+            x = np.sort(y)
+            ys.append(x)
+            longNames.append(xName)
+            units.append(item.units)
+            labels.append(item.label)
+            y = 1. * np.arange(len(x)) / (len(x) - 1)
+            ys.append(y)
+            longNames.append(yName)
+            units.append("")
+            labels.append(item.label)
+
+
+        contents = []
+        # long name
+        contents.append(longNames)
+
+        # units
+        contents.append(units)
+
+        # comments
+        contents.append(labels)
+
+        dataMatrix = np.vstack(ys)
+
+        # write datas
+        for i in range(maxLen):
+            contents.append(dataMatrix[:, i])
+
+        df = pd.DataFrame(contents)
+        df.to_excel(savePath, index=False, header=None)
+        return self
+
+    def exportExcel(self, savePath: str,
+                    xName: str = "Times",
+                    yName: str = "Rate",
+                    xUnit: str = "Second"):
+        """
+        导出数据到Excel
+        :param savePath:
+        :param xName:
+        :param yName:
+        :param xUnit:
+        :return:
+        """
         contents = []
         nodeNames, units, labels, xResult = [], [], [], []
         for item in self.items:
@@ -320,7 +415,7 @@ class ExportBase:
             if len(item.x) > len(xResult):
                 xResult = item.x
         # long name
-        contents.append([xName] + nodeNames)
+        contents.append([xName] + [yName for _ in range(len(nodeNames))])
 
         # units
         contents.append([xUnit] + units)
@@ -331,8 +426,7 @@ class ExportBase:
         ys = [xResult]
         # padding y
         for item in self.items:
-            item.y = np.pad(item.y, (0, len(xResult) - len(item.y)), 'constant', constant_values=(0, 0))
-            ys.append(np.array(item.y).T)
+            ys.append(np.array(np.pad(item.y, (0, len(xResult) - len(item.y)), 'constant', constant_values=(0, 0))).T)
 
         dataMatrix = np.vstack(ys)
 
@@ -342,3 +436,4 @@ class ExportBase:
 
         df = pd.DataFrame(contents)
         df.to_excel(savePath, index=False, header=None)
+        return self
