@@ -4,6 +4,7 @@ from .common import GraphBase, NodeItem, ExportItem, ExportBase
 import numpy as np
 import pandas as pd
 
+
 class DelayType(Enum):
     """
     延迟类型
@@ -247,10 +248,11 @@ class Delay:
 
 
 class DelayExtractBase:
-    def __init__(self):
+    def __init__(self, delay: Delay):
         self.samplingInterval = 1.0
         self.delayType = DelayType.LastDelay
         self.delayTarget = DelayTarget.DelayMS
+        self.delay = delay
 
     def setSamplingInterval(self, samplingInterval: float):
         """
@@ -279,30 +281,27 @@ class DelayExtractBase:
         self.delayTarget = delayTarget
         return self
 
+    def getNode(self, nodeName):
+        return self.delay.getByNode(nodeName)
+
+    def getX(self, node: NodeDelay, nodeId):
+        return node.getX(nodeId, samplingInterval=self.samplingInterval)
+
+    def getY(self, node: NodeDelay, nodeId):
+        return node.getY(nodeId, self.delayType, self.delayTarget, self.samplingInterval)
+
+    def getUnit(self):
+        return DelayTarget.getUnit(self.delayTarget.name)
+
 
 class DelayExport(DelayExtractBase, ExportBase):
     """
     一个用于将延迟统计结果导出到Excel的辅助类
     """
+
     def __init__(self, delay: Delay):
-        def getNode(nodeName):
-            return self.delay.getByNode(nodeName)
-
-        def getX(node: NodeDelay, nodeId):
-            return node.getX(nodeId, samplingInterval=self.samplingInterval)
-
-        def getY(node: NodeDelay, nodeId):
-            return node.getY(nodeId, self.delayType, self.delayTarget, self.samplingInterval)
-
-        def getUnit():
-            return DelayTarget.getUnit(self.delayTarget.name)
-        ExportBase.__init__(self, getNode, getX, getY, getUnit)
-        DelayExtractBase.__init__(self)
-        self.delay = delay
-
-    def exportExcel(self, savePath: str):
-        self.innerExportExcel(savePath, "Times", "Second")
-        return self
+        DelayExtractBase.__init__(self, delay)
+        ExportBase.__init__(self, self.getNode, self.getX, self.getY, self.getUnit)
 
     @staticmethod
     def parse(inputFile: str):
@@ -316,7 +315,7 @@ class DelayGraph(GraphBase, DelayExtractBase):
 
     def __init__(self, delay: Delay):
         GraphBase.__init__(self)
-        DelayExtractBase.__init__(self)
+        DelayExtractBase.__init__(self, delay)
         self.delay = delay
 
     def plot(self, node: str, appId: int, *args,
@@ -347,16 +346,8 @@ class DelayGraph(GraphBase, DelayExtractBase):
                 linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
                 markerfacecolor: str = "none", markersize: float = 6,
                 **kwargs):
-        def getNode(nodeName):
-            return self.delay.getByNode(nodeName)
 
-        def getX(node: NodeDelay, nodeId):
-            return node.getX(nodeId, samplingInterval=self.samplingInterval)
-
-        def getY(node: NodeDelay, nodeId):
-            return node.getY(nodeId, self.delayType, self.delayTarget, self.samplingInterval)
-
-        super().innerPlotSum(nodeList, getNode, getX, getY, *args,
+        super().innerPlotSum(nodeList, self.getNode, self.getX, self.getY, *args,
                              color=color,
                              linewidth=linewidth,
                              linestyle=linestyle,
@@ -372,16 +363,7 @@ class DelayGraph(GraphBase, DelayExtractBase):
                 markerfacecolor: str = "none", markersize: float = 6,
                 **kwargs):
 
-        def getNode(nodeName):
-            return self.delay.getByNode(nodeName)
-
-        def getX(node: NodeDelay, nodeId):
-            return node.getX(nodeId, samplingInterval=self.samplingInterval)
-
-        def getY(node: NodeDelay, nodeId):
-            return node.getY(nodeId, self.delayType, self.delayTarget, self.samplingInterval)
-
-        self.innerPlotAvg(nodeList, getNode, getX, getY, *args,
+        self.innerPlotAvg(nodeList, self.getNode, self.getX, self.getY, *args,
                           color=color,
                           linewidth=linewidth,
                           linestyle=linestyle,
